#!/bin/sh
#=========================================================================
#
# SVMCO udev hotplug event(Linux)
# Copyright FUJITSU LIMITED 2011
#
#=========================================================================
# 2011.02.11 new create
# 2011.04.01 modified file format
#=========================================================================
# $Name: SLINSVMCO-1_0_3-0 $
#=========================================================================

# If your system needs more time to make device data after the hotplug 
# event occured, please delete the "#" of the next line.
#sleep 30

SVMCOPATH=/var/lock/subsys/y30SVmco
HPPATH=/var/fujitsu/SVmco/mmba/hpdata/
SUBSYSTEM=$1
DEVPATH=$2
ACTION=$3

#========================================================================
# make_pci_file()
# outline
#   make pci hotplug file for svmco
#
# parameter
#
# return value
#   0:OK 1:NG
#========================================================================
make_pci_file(){
	#check $DEVPATH format
	echo "$DEVPATH" | grep "^[[:xdigit:]]\{4\}:[[:xdigit:]]\{2\}:[[:xdigit:]]\{2\}\\.[[:digit:]]*$" > /dev/null
	if [ $? -ne 0 ] ; then
		logger -t SVmco -s "W 06298 svmco pci hotplug event PCI_SLOT_NAME doesn't correct. data: $DEVPATH"
		return 1
	fi

	# create file
	TIMESTAMP=`date +%s.%N`
	filename="$HPPATH"/"$SUBSYSTEM---$DEVPATH---$TIMESTAMP---$ACTION"
	echo "[HOTPLUG]"            >  $filename 2>/dev/null
	echo "TIME=$TIMESTAMP"      >> $filename 2>/dev/null
	echo "SUBSYSTEM=$SUBSYSTEM" >> $filename 2>/dev/null
	echo "DEVPATH=$DEVPATH"     >> $filename 2>/dev/null
	echo "ACTION=$ACTION"       >> $filename 2>/dev/null
	if [ ! -r $filename -o ! -s $filename ] ; then
		return 1
	fi

	return 0
}

#========================================================================
# make_scsi_file()
# outline
#   make scsi hotplug file for svmco
#
# parameter
#
# return value
#   0:OK 1:NG
#========================================================================
make_scsi_file(){
	# check whether the device is the target of hotplug
	echo "$DEVPATH" | grep "usb" > /dev/null
	if [ $? -eq 0 ] ; then
		# no logs are written
		return 1
	fi

	#check $DEVPATH format
	echo "$DEVPATH" | grep "host" > /dev/null
	if [ $? -ne 0 ] ; then
		logger -t SVmco -s "W 06298 svmco scsi hotplug event DEVPATH doesn't correct. data: $DEVPATH"
		return 1
	fi

	#touch file
	MODDEVPATH="`echo $DEVPATH | tr \/ \*`"
	TIMESTAMP=`date +%s.%N`
	filename="$HPPATH"/"$SUBSYSTEM---$MODDEVPATH---$TIMESTAMP---$ACTION"
	echo "[HOTPLUG]"            >  $filename 2>/dev/null
	echo "TIME=$TIMESTAMP"      >> $filename 2>/dev/null
	echo "SUBSYSTEM=$SUBSYSTEM" >> $filename 2>/dev/null
	echo "DEVPATH=$DEVPATH"     >> $filename 2>/dev/null
	echo "ACTION=$ACTION"       >> $filename 2>/dev/null
	if [ ! -r $filename -o ! -s $filename ] ; then
		return 1
	fi

	return 0
}

#========================================================================
# main()
# outline
#   make pci or scsi hotplug file for svmco
#
# parameter
#	$1:"pci" or "scsi"
#	$2:"PCI_SLOT_NAME" for pci or "DEVPATH" for scsi
#	$3:action "add" or "remove"
#
# return value
#   0:OK 1:NG
#========================================================================
# check SVMCO is or not
if [ ! -e "$SVMCOPATH" ] ; then
	exit 1
fi

# check number of parameter
if [ $# -ne 3 ] ; then
	exit 1
fi

# check action format
if [ "$ACTION" != "add" -a "$ACTION" != "remove"  ] ; then
	logger -t SVmco -s "W 06297 svmco hotplug $SUBSYSTEM event ACTION hasn't set."
	exit 1
fi

# call file make function
if [ "$SUBSYSTEM" == "pci" ] ; then
	make_pci_file
elif [ "$SUBSYSTEM" == "scsi" ] ; then
	make_scsi_file
else
	logger -t SVmco -s "W 06297 svmco hotplug $SUBSYSTEM event SUBSYSTEM hasn't set."
	exit 1
fi

# check file make fucntion
if [ $? -ne 0 ] ; then
	exit 1
fi

exit 0
