#!/bin/sh
#==============================================================================
# SEND DUMP SCRIPT                                                         
#                                      Copyright FUJITSU LIMITED 2010 - 2011 
#                                                                          
# $Name: SLINSVMCO-1_0_0-5 $                                                                
#==============================================================================
# 2010.04.21 new create                                              
# 2011.02.16 For SVMCO
#==============================================================================

#==============================================================================
# This is the script to send dump summary file to REMCS center.
# This script will return as follows.
#      0 : End successfully
#      1 : Abnormal end
#==============================================================================

file=/tmp/senddump.tmp
LOG_FILE=/var/fujitsu/SVmco/log/mmbm/senddump.log
LOG_DIR=/var/fujitsu/SVmco/log/mmbm/
REMCS_LOG=/var/log/remcs/sirms/log/ez.log
UPTIME=/proc/uptime
SENDLOG=/opt/remcs/sirms/qss_sendlog/sendlog
SUMMARYDIR=/var/log/sadumpsummary
RETURN=1

#==============================================================================
# main process 
#==============================================================================

echo "`date +\"%Y/%m/%d %T\"` I 0001 : Senddump.sh start." >> $LOG_FILE

## serach summary file
summary="`ls $SUMMARYDIR | grep -P Summary-[0-9]\{4\}-[0-9]\{2\}-[0-9]\{2\}-[0-9]\{2\}:[0-9]\{2\} | sort -nr | head -n 1`"

if [ -z "$summary" ] ; then
    ## summary file not found.
    echo "`date +\"%Y/%m/%d %T\"` W 0002 : Summary is not found." >> $LOG_FILE
    exit $RETURN
fi

## get running time
RUNNING_TIME="`cat $UPTIME | cut -d \" \" -f 1 | sed \"s/\([0-9]*\)\.[0-9]*/\1/\"`"

if [ -z "$RUNNING_TIME" ] ; then
    ## runnning time not set.
    echo "`date +\"%Y/%m/%d %T\"` W 0003 : Senddump can't get running time." >> $LOG_FILE
    exit $RETURN
fi
  
## get real-time
REAL_TIME="`date +%s`"

## get making time of dump summary
DATE="`ls --full-time $SUMMARYDIR/$summary | cut -d \" \" -f 6-7`"
DUMP_TIME="`date -d \"$DATE\" +%s`"

if [ -z "$DUMP_TIME" ] ; then
    ## runnning time not set.
    echo "`date +\"%Y/%m/%d %T\"` W 0004 : Senddump can't get making time of dump summary." >> $LOG_FILE
    exit $RETURN
fi

## real-time - dumping time
From_DUMP_to_REALTIME="`expr $REAL_TIME - $DUMP_TIME`"

## Is it the summary immediately after panic ?
if [ "$From_DUMP_to_REALTIME" -lt "$RUNNING_TIME" ] ; then
    echo "`date +\"%Y/%m/%d %T\"` I 0005 : Picking out dump finished." >> $LOG_FILE
    
    $SENDLOG -d -e -l 5000 -a $SUMMARYDIR/$summary > $file 2>&1
    grep "File send successfully." $file > /dev/null 2>&1
    Result=$?
    
    ## check result of sendlog command
    if [ $Result = 0 ] ; then
	## sendlog command nomal end
	echo "`date +\"%Y/%m/%d %T\"` I 0007 : File send successfully." >> $LOG_FILE
	RETURN=0
    else
	echo "`date +\"%Y/%m/%d %T\"` W 0008 : Sendlog command faild." >> $LOG_FILE
	## get remcs log
	cp $REMCS_LOG $LOG_DIR > /dev/null 2>&1
    fi
else
    ## summary file is old
    echo "`date +\"%Y/%m/%d %T\"` W 0006 : Latest summary is not found. Old summary file = $summary" >> $LOG_FILE
fi

rm -rf $file

exit $RETURN
