#!/bin/sh
#/****************************************************************************/
#/* IPTABLES SETUP SCRIPT for PSA-MMB LAN                                    */
#/*                                          Copyright FUJITSU LTD 2010      */
#/*                                                                          */
#/* $Name: SLINSVMCO-1_9_1-0 $                                                     */
#/****************************************************************************/
# Development date : Thu SEP 30 2010

#==============================================================================
# This is the script to set the firewall for PSA-MMB LAN.
# Only FJSVpsa Installer is permitted to execute this script.
# This script will return as follows.
#      0 : End successfully
#      1 : Abnormal end
#==============================================================================

MARK="##The following are settings for PSA-MMB LAN. Please do not change this comment.##"
MARK2="##The following are settings for Internal LAN(PSA-MMB LAN). Please do not change this comment.##"

REJECT_OP="\-j REJECT --reject-with icmp-host-prohibited"
type=$1
rule_num=8

#Check status
/sbin/service iptables status > /dev/null 2>&1

if [ $? -ne 0 ]
    then
case $type in
    'install' | 'manual')
	    echo ""
	    echo "####################################################################################"
	    echo "# setiptables.sh couldn't set iptables setting. because iptables service stopped.  #"
	    echo "# Please set iptables setting by manual.                                           #"
	    echo "# For more detail on how to set iptables setting, refer to the Installation Manual.#"
	    echo "####################################################################################"
	    echo ""
	    ;;
    'uninstall')
    	    echo ""
	    echo "#######################################################################################"
	    echo "# setiptables.sh couldn't delete iptables setting. because iptables service stopped.  #"
	    echo "# Please delete iptables setting by manual.                                           #"
	    echo "# For more detail on how to delete iptables setting, refer to the Installation Manual.#"
	    echo "#######################################################################################"
	    echo ""
	    ;;
esac
    exit 0
fi

case $type in
    'install')
	
	for file in $(find /etc/sysconfig/network-scripts -name "ifcfg-*" ! -name "*.*" -print)
	  do
	  grep -q "$MARK" $file
	  if [ $? -eq 0 ]
	      then
	      IFNAME=$(basename $file|sed "s/ifcfg-//")
	      break
	  fi

	  grep -q "$MARK2" $file
	  if [ $? -eq 0 ]
	      then
	      IFNAME=$(basename $file|sed "s/ifcfg-//")
	      break
	  fi
	done
	
	if [ -z $IFNAME ]
	    then
	    echo "ERROR: setiptables.sh couldn't find the PSA-MMB LAN." >&2
	    exit 1
	fi
	
	iptables -L PSA-MMB_LAN > /dev/null 2>&1
	if [ $? -eq 0 ]
	    then
	    echo "setiptables.sh has already set PSA-MMB_LAN."
	    echo "Please check the setting of the firewall."
	    exit 0
	fi

	iptables -N PSA-MMB_LAN
	iptables -A PSA-MMB_LAN -i lo -j ACCEPT
	iptables -A PSA-MMB_LAN -o lo -j ACCEPT
	iptables -A PSA-MMB_LAN -p icmp --icmp-type echo-request -o $IFNAME -j ACCEPT
	iptables -A PSA-MMB_LAN -p icmp --icmp-type echo-reply -i $IFNAME -j ACCEPT
	iptables -A PSA-MMB_LAN -p udp -i $IFNAME --dport snmp -j ACCEPT
	iptables -A PSA-MMB_LAN -p udp -o $IFNAME --sport snmp -j ACCEPT
	iptables -A PSA-MMB_LAN -p tcp -i $IFNAME --sport 5000 -j ACCEPT
	iptables -A PSA-MMB_LAN -p tcp -o $IFNAME --dport 5000 -j ACCEPT
	
	iptables-save | grep "$REJECT_OP" > /dev/null 2>&1
	RESULT=$?
	
	if [ $RESULT -eq 0 ] ; then

	    TARGET="`iptables-save | grep \"$REJECT_OP\" | grep -v \"FORWARD\" |  cut -d \" \" -f 2`"
	    
	    number="`iptables-save | grep \"\-A $TARGET\" | grep -v \"$REJECT_OP\" | wc -l `"

	    number=`expr $number + 1`
		
	    iptables -I $TARGET $number -j PSA-MMB_LAN
	    
	else
	    iptables -A INPUT -j PSA-MMB_LAN
	fi

	iptables -A OUTPUT -j PSA-MMB_LAN

	/sbin/service iptables save > /dev/null 2>&1
	
	;;
    'uninstall')
	
	iptables-save | grep ":PSA-MMB_LAN" > /dev/null 2>&1
	
	if [ $? -eq 0  ] ; then
	    
	    iptables -F PSA-MMB_LAN 
	    
	    count=`iptables-save | grep PSA-MMB_LAN | grep -v "^:" | wc -l`
	    
	    while [ $count -gt 0 ]
	      do
	      rule="`iptables-save | grep PSA-MMB_LAN | grep -v \"^:\" | head -n 1 | cut -d \" \" -f 2-`"
	      iptables -D $rule
	      count=`expr $count - 1`
	    done
	    
	    iptables -X PSA-MMB_LAN
	    
	    /sbin/service iptables save > /dev/null 2>&1
	fi

	exit 0
	;;
    'manual')
	
	for file in $(find /etc/sysconfig/network-scripts -name "ifcfg-*" ! -name "*.*" -print)
	  do
	  grep -q "$MARK" $file
	  if [ $? -eq 0 ]
	      then
	      IFNAME=$(basename $file|sed "s/ifcfg-//")
	      break
	  fi

         grep -q "$MARK2" $file
          if [ $? -eq 0 ]
              then
              IFNAME=$(basename $file|sed "s/ifcfg-//")
              break
          fi
	done
	
	if [ -z $IFNAME ]
	    then
	    echo "ERROR: setiptables.sh couldn't find the PSA-MMB LAN." >&2
	    exit 1
	fi
	
	iptables-save | grep ":PSA-MMB_LAN" > /dev/null 2>&1

	if [ $? -ne 0 ] ; then
	    iptables -N PSA-MMB_LAN
	fi
	
	count=1
	check1="PSA-MMB_LAN -i lo -j ACCEPT"
	check2="PSA-MMB_LAN -o lo -j ACCEPT"
	check3="PSA-MMB_LAN -o $IFNAME -p icmp -m icmp --icmp-type 8 -j ACCEPT"
	check4="PSA-MMB_LAN -i $IFNAME -p icmp -m icmp --icmp-type 0 -j ACCEPT"
	check5="PSA-MMB_LAN -i $IFNAME -p udp -m udp --dport 161 -j ACCEPT"
	check6="PSA-MMB_LAN -o $IFNAME -p udp -m udp --sport 161 -j ACCEPT"
	check7="PSA-MMB_LAN -i $IFNAME -p tcp -m tcp --sport 5000 -j ACCEPT"
	check8="PSA-MMB_LAN -o $IFNAME -p tcp -m tcp --dport 5000 -j ACCEPT"

	rule1="-i lo -j ACCEPT"
	rule2="-o lo -j ACCEPT"
	rule3="-p icmp --icmp-type echo-request -o $IFNAME -j ACCEPT"
	rule4="-p icmp --icmp-type echo-reply -i $IFNAME -j ACCEPT"
	rule5="-p udp -i $IFNAME --dport snmp -j ACCEPT"
	rule6="-p udp -o $IFNAME --sport snmp -j ACCEPT"
	rule7="-p tcp -i $IFNAME --sport 5000 -j ACCEPT"
	rule8="-p tcp -o $IFNAME --dport 5000 -j ACCEPT"

	

	while [ $count -le $rule_num ]
	  do
	  iptables-save | eval grep \""A \$check$count"\" > /dev/null 2>&1
	  Result=$?
	  if [ $Result -ne 0 ] ; then
	      eval iptables -I PSA-MMB_LAN $count \$rule$count
	  fi
	  count=`expr $count + 1`
	done
	
	/sbin/service iptables save > /dev/null 2>&1
	
	echo ""
	echo "############################################################################"
	echo "# Created the PSA-MMB_LAN chain on your firewall(iptables)                 #"
	echo "# For more detail on how to set firewall, refer to the Installation Manual.#"
	echo "############################################################################"
	echo ""
	exit 0
	;;
    *)
	echo "ERROR: Invalid option"
	echo "Usage: setiptables.sh [install/uninstall/manual]"
	exit 1
	;;
esac

echo "Firewall setting completed."
exit 0
