#!/bin/sh
#/****************************************************************************/
#/* IPTABLES and IP6TABLES SETUP SCRIPT for Management LAN                   */
#/*                                          Copyright FUJITSU LTD 2010-2012 */
#/*                                                                          */
#/* $Name: SLINSVMCO-1_9_1-0 $                                                     */
#/****************************************************************************/
# Development date : Thu SEP 30 2010
#==============================================================================
# This is the script to set the firewall for management LAN.
# Only root user is permitted to execute this script.
# This script will return as follows.
#      0 : End successfully
#      1 : Abnormal end
#==============================================================================

flag=0

usage(){

    echo "Usage: setmlanfw.sh <option> <configure_file>"
    echo "Option is only for IPv6"
    echo "option: -v6"
}

case $# in
    0)
	echo "ERROR: Too few argument."
	usage
	exit 1
    ;;

    1)# For IPv4

	REGEX="^([[:digit:]]+\.){3}[[:digit:]]+($|/[[:digit:]]+$)"
	COMMAND="iptables"
	IPSETCONF="/etc/fujitsu/SVmco/usr/ipsetup.conf"

	if [ ! -f $1 ]
	    then
	    echo "ERROR: Cannot read the file : $1"
	    exit 1
	fi

	TABLECONF=$1
	
	if [ ! -f $IPSETCONF ]
	    then
	    echo "ERROR: Cannot read the file : $IPSETCONF"
	    exit 1
	fi

	;;
    2)# For IPv6

	IPSETCONF="/etc/fujitsu/SVmco/usr/ipsetup_v6.conf"
	COMMAND="ip6tables"
	flag=1 #IPv6 flag on

	if [ $1 != "-v6" ] 
	then
	   echo "ERROR: Invalid option."
	   usage
	   exit 1
	fi

	if [ ! -f $2 ]
	    then
	    echo "ERROR: Cannot read the file : $2"
	    exit 1
	fi	
	
	TABLECONF=$2
	
	if [ ! -f $IPSETCONF ]
	    then
	    echo "ERROR: Cannot read the file : $IPSETCONF"
	    exit 1
	fi
	;;

    *)
	echo "ERROR: Too more argument."
	usage
	exit 1
	;;
esac

/sbin/service $COMMAND status > /dev/null 2>&1

if [ $? -ne 0 ]
then
    echo "setmlanfw.sh couldn't set iptables setting. because $COMMAND service stopped."
    echo "Please set $COMMAND setting by manual."
    echo "For more detail on how to set $COMMAND setting, refer to the Installation Manual."
    exit 1
fi

## Read IPSETCONF
flg=0
while read LINE
  do
  if [ $flg == 0 ]
      then
      echo $LINE|egrep "^ *\[ *NETWORK *\]" >/dev/null
      eff=$?
      if [ $eff == 0 ]
	  then
	  flg=1
      fi
  else
      echo $LINE|egrep "^ *\[.*\]" >/dev/null
      eff=$?
      if [ $eff == 0 ]
	  then
	  flg=0
      fi
      echo $LINE|egrep "^ *ManagementIP *="|grep -v "^\;" >/dev/null
      eff=$?
      if [ $eff == 0 ]
	  then

	  MMIP=$(echo $LINE|cut -d"=" -f 2|tr -d ' ')
	  
	  if [ $flag == 0 ] 
	  then #For IPv4
	      echo $MMIP|egrep "$REGEX" >/dev/null
	  else # For IPv6
	      ./ipcheck i6 $MMIP > /dev/null
	  fi
	  
	  eff=$?
	  if [ $eff == 0 ]
	      then
	      break
	  else
	      echo "ERROR: No IP setting or illegal IP format in $IPSETCONF"
	      exit 1
	  fi
      fi
  fi
done < $IPSETCONF
if [ -x $MMIP ]
    then
    echo "ERROR: No IP setting in $IPSETCONF"
fi

## Read Userfile
flg=0
MMB_NUM=0
while read LINE
  do
  if [ $flg == 0 ]
      then
      echo $LINE|egrep "^ *\[ *PCL *\]" >/dev/null
      eff=$?
      if [ $eff == 0 ]
	  then
	  flg=1
      fi
  else
      echo $LINE|egrep "^ *\[.*\]" >/dev/null
      eff=$?
      if [ $eff == 0 ]
	  then
	  flg=0
      fi

      if [ $flag == 0 ] 
      then # For IPv4
	  echo $LINE|egrep "$REGEX" >/dev/null
      else # For IPv6
	  ./ipcheck i6 $LINE > /dev/null
      fi

      eff=$?
      if [ $eff == 0 ]
	  then
	  MIP[$MMB_NUM]=$LINE
	  MMB_NUM=$(expr $MMB_NUM + 1)
      fi
  fi
done < $TABLECONF

##Check IPs
echo "Management LAN IP address:"
echo "$MMIP"
echo
echo "Source IPs for PRIMECLUSTER Service:"
i=0
while [ $i -ne $MMB_NUM ]
  do
  echo "${MIP[$i]}"
  i=$(expr $i + 1)
done
echo
echo "Press \"Y\" to confirm above settings, \"N\" to cancel all settings"
while :
  do
  read -p '>' A
  case "$A" in
      "Y") break;;
      "y") break;;
      "N") exit 1;;
      "n") exit 1;;
      *) echo "Press \"Y\" or \"N\"" ;;
  esac
done

$COMMAND -L MMLAN > /dev/null 2>&1
eff=$?
if [ $eff == 0 ]
    then
    echo "Already set iptables"
    echo "Please check the setting of the firewall."
    exit 0
fi

$COMMAND -N MMLAN
i=0
while [ $i -ne $MMB_NUM ]
  do

  $COMMAND -A MMLAN -p udp -s ${MIP[$i]} -d ${MMIP} --dport 7000:7100 -j ACCEPT
  $COMMAND -A MMLAN -p udp -d ${MIP[$i]} -s ${MMIP} --sport 7000:7100 -j ACCEPT
  $COMMAND -A MMLAN -p udp -s ${MIP[$i]} -d ${MMIP} --dport snmptrap -j ACCEPT
  $COMMAND -A MMLAN -p udp -d ${MIP[$i]} -s ${MMIP} --sport snmptrap -j ACCEPT
  i=$(expr $i + 1)

done

echo "############################################################################"
echo "# Created the MMLAN chain on your firewall($COMMAND)                       #"
echo "# For more detail on how to set firewall, refer to the Installation Manual.#"
echo "############################################################################"

/sbin/service $COMMAND save > /dev/null 2>&1

echo "The setting was completed"
exit 0
