#!/bin/sh
#==============================================================================
# SET MODULE SCRIPT
#                                      Copyright FUJITSU LIMITED 2015
#
# $Name: SLINSVMCO-1_10_2-1 $
#==============================================================================

#==============================================================================
# This script judges the architecture of ServerView Agent, and generates 
# the link of HWSendMSG libraries. 
#
# This script will return as follows.
#      0 : End successfully
#      1 : Abnormal end
#==============================================================================

LOG_FILE=/var/fujitsu/SVmco/log/pm2/setmodule.log

# Check the existence of the libhwsendmsg.so
if [ ! -e /opt/fujitsu/SVmco/lib/libhwsendmsg.so ] ; then
    arch_lib=2 # 0:x64 1:x86 2:others
else
 # Check the architecture of libhwsendmsg.so
 ls -l /opt/fujitsu/SVmco/lib/libhwsendmsg.so | grep x64 > /dev/null 2>&1
 arch_lib=$? # 0:x64 1:x86

 if [ $arch_lib -eq 0 ] ; then
    arch=64bit
 else
    arch=32bit
 fi
fi

# Check to the installation of ServerView Agent.
result="`rpm -qa | grep srvmagt-agents | wc -l`"

if [ $result -eq 0 ] ; then
    echo "HWSendMSG library: $arch version installed." > $LOG_FILE
    echo "ServerView Agent : Not installed" >> $LOG_FILE
    exit 0
elif [ $result -gt 1 ] ; then
    echo "More than one ServerView Agent is installed." > $LOG_FILE
    logger -t SVmco "W 05502 More than one ServerView Agent is installed."
    exit 1
fi

# Check the architecture of ServerView Agent
rpm -qa --qf '%{name}-%{version}-%{release}.%{arch}.rpm\n' | grep srvmagt-agents | grep x86_64 > /dev/null 2>&1
arch_svagt=$?

if [ $arch_svagt -eq 0 ] ; then
    arch2=64bit
else
    arch2=32bit
fi

# Compere the he architecture of HWSendMSG library and ServerView Agent
if [ $arch_svagt -eq $arch_lib ] ; then
    echo "HWSendMSG library: $arch version installed." > $LOG_FILE
    echo "ServerView Agent : $arch2 version installed." >> $LOG_FILE
    exit 0
else

# Create the symbolic link of libhwsendmsg library.

    if [ $arch_svagt -eq 0 ] ; then
	ln -fs arch/x64/libhwsendmsg.so.1.0 /opt/fujitsu/SVmco/lib/libhwsendmsg.so
	result=$?
    else
	ln -fs arch/x86/libhwsendmsg.so.1.0 /opt/fujitsu/SVmco/lib/libhwsendmsg.so
	result=$?
    fi

    if [ $result -ne 0 ] ; then
        echo "Failed to create the link of libhwsendmsg.so.1.0" > $LOG_FILE
	logger -t SVmco "W 05501 Failed to create the link of libhwsendmsg.so.1.0"
	exit 1
    else
	echo "HWSendMSG library: $arch version installed." > $LOG_FILE
	echo "ServerView Agent : $arch2 version installed." >> $LOG_FILE
	echo "Linked the $arch2 version HWSendMSG library." >> $LOG_FILE
    fi
fi

exit 0