#!/bin/sh
#/****************************************************************************/
#/* SNMP SETUP SCRIPT                                                        */
#/*                                      Copyright FUJITSU LIMITED 2004-2009 */
#/*                                                                          */
#/* $Name: SLINSVMCO-1_9_1-0 $                                                                */
#/****************************************************************************/
# Development date : Wed Dec 10 2008
# For RHEL6        : Tue Aug 24 2010 F.Nakamura  
#==============================================================================
# This is the script to add or remove the snmp setting for SVMCO.
# Only SVmco Installer is permitted to execute this script.
# This script will return as follows.
#      0 : End successfully
#      1 : Abnormal end
#==============================================================================

SNMPCONFFILE=/etc/snmp/snmpd.conf

# 2010.8.24 added and modified*
SNMPPSWDDIR1=/var/net-snmp/
SNMPPSWDDIR2=/var/lib/net-snmp/
#******************************

SNMPPSWDFILE=snmpd.conf
SNMPTRPDFILE=/etc/snmp/snmptrapd.conf
ENCFILE=/var/fujitsu/SVmco/mmba/data
ERRORFILE=/var/fujitsu/SVmco/mmba/error
SNMPTRAPRC=/etc/init.d/snmptrapd

STARTLINE="## Setup for SVmco Please do not remove the following lines ##"
STOPLINE="## End of Setup for SVmco ##"

SNMPOPT=/etc/sysconfig/snmpd.options
SNMPOPTBK=/var/tmp/snmpd.options.org

SNMPCONFTMP=/tmp/snmpd.conf
TRAPCONFTMP=/tmp/snmptrapd.conf

SNMPTRAPRCNEW=/etc/init.d/snmptrapd.rpmnew
SNMPTRAPRCBK=/var/tmp/snmptrapd.org
SNMPTRAPOPT=""

# 2010.8.24 added and modified****************
SNMPTRAPFILE=""
SNMPTRAPFILE1=snmptrapd
SNMPTRAPFILE2=snmptrapd.options

SNMPTRAPOPTBK=""
SNMPTRAPOPTBK1=/var/tmp/snmptrapd.org
SNMPTRAPOPTBK2=/var/tmp/snmptrapd.options.org
#********************************************

SNMPHOST=localhost
SNMPCOMMUNITY=mcoprivate
SNMPVERSION=v1
AGENTXTIMER=360
AGENTXRETRIS=0
SNMPACCOUNT=svmco
TRAPDOID=".1.3.6.1.4.1.3183.1.1.0.12611328 \
		  .1.3.6.1.4.1.3183.1.1.0.12611329 \
		  .1.3.6.1.4.1.3183.1.1.0.12611330 \
		  .1.3.6.1.4.1.3183.1.1.0.12611331 \
		  .1.3.6.1.4.1.3183.1.1.0.12611332 \
		  .1.3.6.1.4.1.3183.1.1.0.12611333 \
		  .1.3.6.1.4.1.3183.1.1.0.12611334 \
		  .1.3.6.1.4.1.3183.1.1.0.12611335 \
		  .1.3.6.1.4.1.3183.1.1.0.12611336 \
		  .1.3.6.1.4.1.3183.1.1.0.12611337 \
 		  .1.3.6.1.4.1.3183.1.1.0.12611338"
TRAPCMD=/opt/fujitsu/SVmco/bin/pcxtrp
TRAPOPT=/
TRAPCOMMUNITY=public


#-----------------------------------------------------------------------------
# snmptrapd options conversion function
#
#  Brief;
#  snmptrapd options setting for SVMCO (-Lsd <--> -n -Lf /dev/null)
#  If target word is not found, options setting is ignored.
#
#  Args;
#  $1       :target file path
#  $2       :target word
#  $3       :changes (for sed command)
#  Return;
#  0        :Normal end
#-----------------------------------------------------------------------------
function trapd_opt_conv()
{
	filepath=$1
	targetwd=$2
	change=$3

	ncnt=`cat $filepath | wc -l`
	zcnt=`grep $ $filepath | wc -l`
	
	if [ $ncnt -ne $zcnt ]
	then
	    echo "" >> $filepath
	fi
	
	touch $filepath.org
	chmod --reference $filepath $filepath.org
	
        bkup=$IFS
        IFS=
        
        exec 3< $filepath
        
        while read target 0<&3
        do
	    # Check whether OPTION line or not.(ignore comment line)
	    targetchk=`echo $target | egrep "$targetwd" | wc -w`
	    
	    # In case of targetwd line, change .
	    if [ $targetchk -ne 0 ]
	    then
	        temp=`echo  "$target" | sed "$change"`
	        echo "$temp" >> $filepath.org
	    else
	        echo "$target" >> $filepath.org
	    fi
	    
	done
	
	mv $filepath.org $filepath
	
        exec 3<&-
        
        IFS=$bkup
	
	return 0
}


#-----------------------------------------------------------------------------
# main
#
#  Brief;
#  snmp setup function
#
#  Args;
#
#  Return;
#  0        :Normal end
#  1        :Abnormal end
#-----------------------------------------------------------------------------

type=$1

#---------------------------------- auth check ------------------------------------
WHO=`whoami | egrep "^root$" | wc -l`
if [ $WHO -ne 1 ]
	then
		echo "ERROR: snmpsetup.sh : Operation not permitted. root only"
		exit 1
fi

level1=`/sbin/runlevel | grep -P 'unknown|..S' | wc -l`


#------------------------- snmpd.conf definition start ----------------------------

if ! [ -f $SNMPCONFFILE -a -w $SNMPCONFFILE ]
then
	echo "ERROR: Can't find the file : \"$SNMPCONFFILE\""
	exit 1
fi

ncnt=`cat $SNMPCONFFILE | wc -l`
zcnt=`grep $ $SNMPCONFFILE | wc -l`

case $type in
	'install')

		STARTCHK=`grep "$STARTLINE" $SNMPCONFFILE | wc -w`
		if [ $STARTCHK -eq 0 ]
		then
			if [ $ncnt -ne $zcnt ]
				then
				echo "" >> $SNMPCONFFILE
			fi
			echo "" >> $SNMPCONFFILE
			echo "$STARTLINE"  >> $SNMPCONFFILE
			echo "com2sec mcolocal $SNMPHOST $SNMPCOMMUNITY" >> $SNMPCONFFILE
			echo "group McoRWGroup $SNMPVERSION mcolocal" >> $SNMPCONFFILE
			echo "view fujitsu included .1.3.6.1.4.1.231.2 ff" >> $SNMPCONFFILE
			echo "access McoRWGroup \"\" any noauth exact fujitsu fujitsu none"  >> $SNMPCONFFILE
			echo "" >> $SNMPCONFFILE
			echo "rouser $SNMPACCOUNT" >> $SNMPCONFFILE
			echo "" >> $SNMPCONFFILE
			echo "$STOPLINE" >> $SNMPCONFFILE
			echo "" >> $SNMPCONFFILE
		fi
		;;

	'upinstall')
		;;

	'uninstall')

		startl=`grep -n "$STARTLINE" $SNMPCONFFILE | cut -d: -f1`
		stopl=`grep -n "$STOPLINE" $SNMPCONFFILE | cut -d: -f1`

		if ! [ -z "$startl" -o -z "$stopl" ]
			then
			if [ $startl -lt $stopl ]
				then
				touch $SNMPCONFTMP
				chmod --reference $SNMPCONFFILE $SNMPCONFTMP
				head -n `expr $startl - 1` $SNMPCONFFILE > $SNMPCONFTMP
				tail -n `expr $zcnt - $stopl` $SNMPCONFFILE >> $SNMPCONFTMP
				mv $SNMPCONFTMP $SNMPCONFFILE

				if [ -e /etc/rsyslog.conf ]
                                    then
                                    restorecon -F $SNMPCONFFILE
                                fi
			fi
		fi
		;;

	*)
		echo "ERROR: Invalid option 'S1'"
		echo "Usage: snmpsetup.sh [install/upinstall/uninstall]"
		exit 1
		;;
esac

#------------------------- snmpd.options definition start ----------------------------

case $type in
	'install')
		if [ ! -f $SNMPOPT ]; then
		    touch $SNMPOPT
		    echo "OPTIONS=\"-LS 5d -Lf /dev/null -p /var/run/snmpd.pid -a\"" >> $SNMPOPT
		else
		    
		    cp $SNMPOPT $SNMPOPTBK
		    
		    ncnt=`cat $SNMPOPT | wc -l`
		    zcnt=`grep $ $SNMPOPT | wc -l`
		    
		    if [ $ncnt -ne $zcnt ]
			then
			echo "" >> $SNMPOPT
		    fi
		    
		    
		    l1=`egrep -c "^[[:space:]]*OPTIONS" $SNMPOPT`
		    l2=`egrep -c "^[[:space:]]*OPTIONS[[:space:]]*=[[:space:]]*\"[[:space:]]*.{OPTIONS}" $SNMPOPT`
		    
		    if [ $l1 -eq 0 ];then
		        echo "OPTIONS=\"-LS 5d -Lf /dev/null -p /var/run/snmpd.pid -a\"" >> $SNMPOPT
		    elif [ $l1 -eq $l2 ]; then
		        touch $SNMPOPT.org
		        chmod --reference $SNMPOPT $SNMPOPT.org
		        
		        echo "OPTIONS=\"-LS 5d -Lf /dev/null -p /var/run/snmpd.pid -a\"" >> $SNMPOPT.org
		        cat $SNMPOPT >> $SNMPOPT.org
		        mv $SNMPOPT.org $SNMPOPT
		    else
		        trapd_opt_conv $SNMPOPT "^[[:space:]]*OPTIONS" "s/-Lsd/-LS 5d/"
		    fi
		fi

		;;

	'uninstall')
		if [ -f $SNMPTRAPOPT ]; then
		    trapd_opt_conv $SNMPOPT "^[[:space:]]*OPTIONS" "s/-LS 5d/-Lsd/"
		fi

		;;

esac


#--------------------------------- snmpd start/stop -------------------------------------

case $type in
	'install')
		if [ $level1 -ne 1 ]; then
			/sbin/service snmpd restart > /dev/null 2>&1
		fi

		/sbin/service snmpd stop > /dev/null 2>&1

		;;
esac

#------------------------- snmpv3 passwd definition start -------------------------------

# ** 2010.8.25 added. For RHEL6 (move local state file from /var/net-snmp/ to /var/lib/net-snmp v5.4.2.1-13) **
NETSNMPVL=`rpm -qa net-snmp | grep "net-snmp-5\.[0-3]" | wc -l`

if [ $NETSNMPVL -eq 0 ]
then
    SNMPPSWDDIR=$SNMPPSWDDIR2
else
    SNMPPSWDDIR=$SNMPPSWDDIR1
fi
# 2010.8.25 **************************************************

if [ ! -d $SNMPPSWDDIR ]
then
	mkdir $SNMPPSWDDIR
fi

if ! [ -f $SNMPPSWDDIR$SNMPPSWDFILE -a -w $SNMPPSWDDIR$SNMPPSWDFILE ]
then
	touch $SNMPPSWDDIR$SNMPPSWDFILE
fi

case $type in
	'install')

		./snmp_proxy -q pleiades $SNMPPSWDDIR$SNMPPSWDFILE $SNMPACCOUNT $ENCFILE $level1 >> $ERRORFILE

		/sbin/service snmpd stop  > /dev/null 2>&1

		;;
esac


#--------------------------------- snmptrapd stop -------------------------------------

case $type in
	'install'|'upinstall')

		/sbin/service snmptrapd stop > /dev/null 2>&1
		;;

	'uninstall')

		/sbin/service snmptrapd stop > /dev/null 2>&1
		;;
esac

#------------------------------ snmptrapd options setting start ----------------------

if ! [ -f $SNMPTRAPRC -a -w $SNMPTRAPRC ]
then
	echo "ERROR: Can't find the file : \"$SNMPTRAPRC\""
	exit 1
fi

if [ -f $SNMPTRAPRC.org ]
then
	rm -f $SNMPTRAPRC.org
fi

case $type in
	'upinstall')
		#
		# init script backup
		#
		cp $SNMPTRAPRC $SNMPTRAPRCBK
		
		#
		# option setting check
		#
		chg=0
		n1=`egrep -c "^[[:space:]]*OPTIONS" $SNMPTRAPRC`
		n2=`egrep -c "^[[:space:]]*OPTIONS[[:space:]]*=[[:space:]]*\"[[:space:]]*-n -Lf \/dev\/null -p \/var\/run\/snmptrapd.pid\"$" $SNMPTRAPRC`
		if [ $n1 -ne $n2 ]; then
			chg=1
		fi
		
		#
		# snmptrapd init script repair
		#
		if [ $chg -eq 0 -a -f $SNMPTRAPRCNEW ];then
		    mv $SNMPTRAPRCNEW $SNMPTRAPRC
		else
		    n3=`egrep -c "([[:space:]]*|\")-n -Lf \/dev\/null([[:space:]]*|\")" $SNMPTRAPRC`
		    if [ $n3 -ne 0 ]; then
		        trapd_opt_conv $SNMPTRAPRC "^[[:space:]]*OPTIONS" "s/-n -Lf \/dev\/null/-Lsd/"
		    fi
		fi

		;;
esac


#
# snmptrapd.options file path check
#
l1=0

# ** 2010.8.24 For RHEL6
# (introduce /etc/sysconfig/snmptrapd. Use it to specify snmptrapd command
#  line options.  /etc/sysconfig/snmptrapd.options is not used anymore. v.5.5-2) ***

NETSNMPVL=`rpm -qa net-snmp | grep "net-snmp-5\.[0-4]" | wc -l`
if [ $NETSNMPVL -eq 0 ]
then
    SNMPTRAPFILE=$SNMPTRAPFILE1
    SNMPTRAPOPTBK=$SNMPTRAPOPTBK1
else
    SNMPTRAPFILE=$SNMPTRAPFILE2
    SNMPTRAPOPTBK=$SNMPTRAPOPTBK2
fi
# 2010.8.24 **************************************************

while read target ;do
    targetchk1=`echo $target | egrep "^[[:space:]]*\.[[:space:]]\/([[:alnum:]]|\/)*\/$SNMPTRAPFILE" | wc -l`
    targetchk2=`echo $target | egrep "^[[:space:]]*fi$" | wc -l`
    targetchk3=`echo $target | egrep "^[[:space:]]*OPTIONS[[:space:]]*=[[:space:]]*\"[[:space:]]*(-Lsd|-n -Lf \/dev\/null)" | wc -l`
    
    # In case of snmptrapd.options line, .
    if [ $targetchk1 -ne 0 ]; then
        set $(echo $target)
        SNMPTRAPOPT=$2
        l1=1
    fi
    
    # In case of fi line, .
    if [ $l1 -eq 1 -a $targetchk2 -ne 0 ]; then
        l1=2
    fi
    
    # In case of OPTIONS line, .
    if [ $l1 -eq 2 -a $targetchk3 -ne 0 ]; then
        SNMPTRAPOPT=$SNMPTRAPRC
    fi
    
done < $SNMPTRAPRC


#
# snmptrapd option setting for SVMCO
#
case $type in
	'install'|'upinstall')
		if [ ! -f $SNMPTRAPOPT ]; then
		    touch $SNMPTRAPOPT
		    chmod 755 $SNMPTRAPOPT
		    echo "OPTIONS=\"-n -Lf /dev/null -p /var/run/snmptrapd.pid\"" >> $SNMPTRAPOPT
		else
		    
		    cp $SNMPTRAPOPT $SNMPTRAPOPTBK
		    
		    ncnt=`cat $SNMPTRAPOPT | wc -l`
		    zcnt=`grep $ $SNMPTRAPOPT | wc -l`
		    
		    if [ $ncnt -ne $zcnt ]
			then
			echo "" >> $SNMPTRAPOPT
		    fi
		    
		    
		    l1=`egrep -c "^[[:space:]]*OPTIONS" $SNMPTRAPOPT`
		    l2=`egrep -c "^[[:space:]]*OPTIONS[[:space:]]*=[[:space:]]*\"[[:space:]]*.{OPTIONS}" $SNMPTRAPOPT`
		    
		    if [ $l1 -eq 0 ];then
		        echo "OPTIONS=\"-n -Lf /dev/null -p /var/run/snmptrapd.pid\"" >> $SNMPTRAPOPT
		    elif [ $l1 -eq $l2 ]; then
		        touch $SNMPTRAPOPT.org
		        chmod --reference $SNMPTRAPOPT $SNMPTRAPOPT.org
		        
		        echo "OPTIONS=\"-n -Lf /dev/null -p /var/run/snmptrapd.pid\"" >> $SNMPTRAPOPT.org
		        cat $SNMPTRAPOPT >> $SNMPTRAPOPT.org
		        mv $SNMPTRAPOPT.org $SNMPTRAPOPT
		        
		    else
		        trapd_opt_conv $SNMPTRAPOPT "^[[:space:]]*OPTIONS" "s/-Lsd/-n -Lf \/dev\/null/"
		    fi
		fi

		;;

	'uninstall')
		if [ -f $SNMPTRAPOPT ]; then
		    trapd_opt_conv $SNMPTRAPOPT "^[[:space:]]*OPTIONS" "s/-n -Lf \/dev\/null/-Lsd/"
		fi

		;;

esac

#---------------------------- snmptrapd definition start -----------------------------------

case $type in
	'install')
 
		if ! [ -f $SNMPTRPDFILE ]
		then
			echo "" >> $SNMPTRPDFILE
			echo "$STARTLINE"  >> $SNMPTRPDFILE
			NETSNMPVL1=`rpm -qa net-snmp | grep "net-snmp-[0-4]" | wc -l`
			if [ $NETSNMPVL1 -eq 0 ]
			then
				NETSNMPVL2=`rpm -qa net-snmp | grep "net-snmp-5\.[0-2]\." | wc -l`
				if [ $NETSNMPVL2 -eq 0 ]
				then
				        echo "snmpTrapdAddr udp:162,udp6:162" >> $SNMPTRPDFILE
      					echo "authCommunity execute $TRAPCOMMUNITY" >> $SNMPTRPDFILE
					echo "" >> $SNMPTRPDFILE
				fi
			fi
			for INPUTOID in $TRAPDOID
				do
					echo "traphandle $INPUTOID $TRAPCMD $TRAPOPT" >> $SNMPTRPDFILE
				done
			echo "$STOPLINE" >> $SNMPTRPDFILE
			echo "" >> $SNMPTRPDFILE
		else
			STARTCHK=`grep "$STARTLINE" $SNMPTRPDFILE | wc -w`
			if [ $STARTCHK -eq 0 ]
			then
				ncnt=`cat $SNMPTRPDFILE | wc -l`
				zcnt=`grep $ $SNMPTRPDFILE | wc -l`
				if [ $ncnt -ne $zcnt ]
					then
					echo "" >> $SNMPTRPDFILE
				fi
				echo "" >> $SNMPTRPDFILE
				echo "$STARTLINE"  >> $SNMPTRPDFILE
				NETSNMPVL1=`rpm -qa net-snmp | grep "net-snmp-[0-4]" | wc -l`
				if [ $NETSNMPVL1 -eq 0 ]
				then
					NETSNMPVL2=`rpm -qa net-snmp | grep "net-snmp-5\.[0-2]\." | wc -l`
					if [ $NETSNMPVL2 -eq 0 ]
					then
					        echo "snmpTrapdAddr udp:162,udp6:162" >> $SNMPTRPDFILE
						echo "authCommunity execute $TRAPCOMMUNITY" >> $SNMPTRPDFILE
						echo "" >> $SNMPTRPDFILE
					fi
				fi
				for INPUTOID in $TRAPDOID
					do
						echo "traphandle $INPUTOID $TRAPCMD $TRAPOPT" >> $SNMPTRPDFILE
					done
				echo "$STOPLINE" >> $SNMPTRPDFILE
				echo "" >> $SNMPTRPDFILE
			fi
		fi
		;;

    'upinstall')
                ## Delete SVMCO setting
                zcnt=`grep $ $SNMPTRPDFILE | wc -l`
                startl=`grep -n "$STARTLINE" $SNMPTRPDFILE | cut -d: -f1`
                stopl=`grep -n "$STOPLINE" $SNMPTRPDFILE | cut -d: -f1`

		if ! [ -z "$startl" -o -z "$stopl" ]
			then
			if [ $startl -lt $stopl ]
				then
				touch $TRAPCONFTMP
				chmod --reference $SNMPTRPDFILE $TRAPCONFTMP
				head -n `expr $startl - 1` $SNMPTRPDFILE > $TRAPCONFTMP
				tail -n `expr $zcnt - $stopl` $SNMPTRPDFILE >> $TRAPCONFTMP
				mv $TRAPCONFTMP $SNMPTRPDFILE

				if [ -e /etc/rsyslog.conf ]
                                    then
                                    restorecon -F $SNMPTRPDFILE
                                fi
			fi
		fi
                
                ## Add SVMCO setting
		if ! [ -f $SNMPTRPDFILE ]
		then
			echo "" >> $SNMPTRPDFILE
			echo "$STARTLINE"  >> $SNMPTRPDFILE
			NETSNMPVL1=`rpm -qa net-snmp | grep "net-snmp-[0-4]" | wc -l`
			if [ $NETSNMPVL1 -eq 0 ]
			then
				NETSNMPVL2=`rpm -qa net-snmp | grep "net-snmp-5\.[0-2]\." | wc -l`
				if [ $NETSNMPVL2 -eq 0 ]
				then
				        echo "snmpTrapdAddr udp:162,udp6:162" >> $SNMPTRPDFILE
					echo "authCommunity execute $TRAPCOMMUNITY" >> $SNMPTRPDFILE
					echo "" >> $SNMPTRPDFILE
				fi
			fi
			for INPUTOID in $TRAPDOID
				do
					echo "traphandle $INPUTOID $TRAPCMD $TRAPOPT" >> $SNMPTRPDFILE
				done
			echo "$STOPLINE" >> $SNMPTRPDFILE
			echo "" >> $SNMPTRPDFILE
		else
			STARTCHK=`grep "$STARTLINE" $SNMPTRPDFILE | wc -w`
			if [ $STARTCHK -eq 0 ]
			then
				ncnt=`cat $SNMPTRPDFILE | wc -l`
				zcnt=`grep $ $SNMPTRPDFILE | wc -l`
				if [ $ncnt -ne $zcnt ]
					then
					echo "" >> $SNMPTRPDFILE
				fi
				echo "" >> $SNMPTRPDFILE
				echo "$STARTLINE"  >> $SNMPTRPDFILE
				NETSNMPVL1=`rpm -qa net-snmp | grep "net-snmp-[0-4]" | wc -l`
				if [ $NETSNMPVL1 -eq 0 ]
				then
					NETSNMPVL2=`rpm -qa net-snmp | grep "net-snmp-5\.[0-2]\." | wc -l`
					if [ $NETSNMPVL2 -eq 0 ]
					then
	    				        echo "snmpTrapdAddr udp:162,udp6:162" >> $SNMPTRPDFILE
						echo "authCommunity execute $TRAPCOMMUNITY" >> $SNMPTRPDFILE
						echo "" >> $SNMPTRPDFILE
					fi
				fi
				for INPUTOID in $TRAPDOID
					do
						echo "traphandle $INPUTOID $TRAPCMD $TRAPOPT" >> $SNMPTRPDFILE
					done
				echo "$STOPLINE" >> $SNMPTRPDFILE
				echo "" >> $SNMPTRPDFILE
			fi
		fi
		;;
		
	'uninstall')

		zcnt=`grep $ $SNMPTRPDFILE | wc -l`
		startl=`grep -n "$STARTLINE" $SNMPTRPDFILE | cut -d: -f1`
		stopl=`grep -n "$STOPLINE" $SNMPTRPDFILE | cut -d: -f1`

		if ! [ -z "$startl" -o -z "$stopl" ]
			then
			if [ $startl -lt $stopl ]
				then
				touch $TRAPCONFTMP
				chmod --reference $SNMPTRPDFILE $TRAPCONFTMP
				head -n `expr $startl - 1` $SNMPTRPDFILE > $TRAPCONFTMP
				tail -n `expr $zcnt - $stopl` $SNMPTRPDFILE >> $TRAPCONFTMP
				mv $TRAPCONFTMP $SNMPTRPDFILE

				if [ -e /etc/rsyslog.conf ]
                                    then
                                    restorecon -F $SNMPTRPDFILE
                                fi
			fi
		fi
		;;

esac


#------------------------------ snmpd/snmptrapd start  ---------------------------------

case $type in
	'install')
		
		if [ $level1 -ne 1 ]; then
			/sbin/service snmpd start  > /dev/null 2>&1
		fi
		chkconfig --add snmpd
		chkconfig snmpd on

		if [ $level1 -ne 1 ]; then
			/sbin/service snmptrapd start  > /dev/null 2>&1
		fi
		chkconfig --add snmptrapd
		chkconfig snmptrapd on

		;;

	'upinstall')
		if [ $level1 -ne 1 ]; then
			/sbin/service snmptrapd start  > /dev/null 2>&1
		fi

		;;

esac

exit 0
